function varargout = log_adj_sub(varargin)
% LOG_ADJ_SUB M-file for log_adj_sub.fig
%      LOG_ADJ_SUB, by itself, creates a new LOG_ADJ_SUB or raises the existing
%      singleton*.
%
%      H = LOG_ADJ_SUB returns the handle to a new LOG_ADJ_SUB or the handle to
%      the existing singleton*.
%
%      LOG_ADJ_SUB('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in LOG_ADJ_SUB.M with the given input arguments.
%
%      LOG_ADJ_SUB('Property','Value',...) creates a new LOG_ADJ_SUB or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before log_adj_sub_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to log_adj_sub_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help log_adj_sub

% Last Modified by GUIDE v2.5 06-Feb-2009 12:54:00

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @log_adj_sub_OpeningFcn, ...
                   'gui_OutputFcn',  @log_adj_sub_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before log_adj_sub is made visible.
function log_adj_sub_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to log_adj_sub (see VARARGIN)

% Choose default command line output for log_adj_sub
handles.output = hObject;
set(handles.edit1,'String','1');
set(handles.edit2,'String','10');
% Update handles structure
guidata(hObject, handles);

% UIWAIT makes log_adj_sub wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = log_adj_sub_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;



function edit1_Callback(hObject, eventdata, handles)
% hObject    handle to edit1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1 as text
%        str2double(get(hObject,'String')) returns contents of edit1 as a double


% --- Executes during object creation, after setting all properties.
function edit1_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit2_Callback(hObject, eventdata, handles)
% hObject    handle to edit2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit2 as text
%        str2double(get(hObject,'String')) returns contents of edit2 as a double


% --- Executes during object creation, after setting all properties.
function edit2_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes on button press in pushbutton1.
function pushbutton1_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
kmin=str2num(get(handles.edit1,'String'))
kmax=str2num(get(handles.edit2,'String'))
handles.kmin=kmin
handles.kmax=kmax
haypar=0
handles.haypar=haypar
if kmax<=kmin
    errordlg('El valor maximo debe ser mayor al menor');
else
    handles1=handles;
    handles1.kmin=handles.kmin
    handles1.kmax=handles.kmax
    save kmin handles1;
    save kmax handles1;
    haypar=1
    handles.haypar=haypar
    handles1.haypar=handles.haypar
  
    save haypar handles1;
    guidata(hObject, handles);

    close(log_adj_sub);
end


% --- Executes on button press in pushbutton2.
function pushbutton2_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
 handles1.haypar=0;
 save haypar handles1;
guidata(hObject, handles);

 close(log_adj_sub);
